@@ -1,4 +1,4 @@
-# $Id: TranscodeVideo.pm,v 1.10.2.2 2003/06/25 20:48:15 joern Exp $
+# $Id: TranscodeVideo.pm,v 1.10.2.4 2003/10/26 14:25:05 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -95,7 +95,22 @@ sub init {
 sub get_diskspace_needed {
 	my $self = shift; $self->trace_in;
 
-	return $self->title->tc_target_size * 1024;
+	my $title = $self->title;
+
+	return 0 if $title->tc_multipass and $self->pass == 1;
+
+	$title->set_actual_chapter($self->chapter);
+
+	my $bc = Video::DVDRip::BitrateCalc->new (
+		title		=> $title,
+		with_sheet	=> 0,
+	);
+
+	$bc->calculate_video_bitrate;
+
+	$title->set_actual_chapter(undef);
+
+	return int(($bc->video_size + $bc->non_video_size)*1024);
 }
 
 sub get_diskspace_freed {
