@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.41.2.1 2003/03/31 08:54:34 joern Exp $
+# $Id: Project.pm,v 1.41.2.3 2003/10/26 10:38:03 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -128,7 +128,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.41.2.1 2003/03/31 08:54:34 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.41.2.3 2003/10/26 10:38:03 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -166,6 +166,10 @@ sub get_save_data {
 	$dd->Purity(1);
 	my $data = $dd->Dump;
 
+	my $end_marker = "}, 'Video::DVDRip::Project' );\n";
+	my $end_marker_quoted = quotemeta($end_marker);
+	$data =~ s/$end_marker_quoted.*/$end_marker/so;
+
 	$self->set_last_saved_data($last_saved_data);
 	$self->set_filename ($filename);
 
@@ -203,7 +207,11 @@ sub load {
 	
 	my $fh = FileHandle->new;
 	open ($fh, $filename) or croak "can't read $filename";
-	my $data = join ('', <$fh>);
+	my $data;
+	while (<$fh>) {
+		$data .= $_;
+		last if $data =~ /Video::DVDRip::Project/;
+	}
 	close $fh;
 
 	croak "File is no dvd::rip file"
@@ -232,6 +240,8 @@ sub load {
 	%{$self} = %{$project};
 
 	$self->content->set_project ($self);
+	$self->check_for_deleted_filters;
+
 	$self->set_last_saved_data ($save_data);
 
 	1;
@@ -405,4 +415,33 @@ sub convert_from_old_version {
 	1;
 }
 
+sub check_for_deleted_filters {
+	my $self = shift;
+
+	foreach my $title ( values %{$self->content->titles} ) {
+		my $selected_filters = $title->tc_filter_settings
+					     ->filters;
+		my @remove_filters;
+		my $i = 0;
+		foreach my $filter_instance ( @{$selected_filters} ) {
+			eval { $filter_instance->get_filter };
+			if ( $@ ) {
+				print (
+					"Warning: filter '".
+					$filter_instance->filter_name.
+					"' removed from title #".
+					$title->nr.
+					" because this transcode installation ".
+					"does not provide it anymore.\n"
+				);
+				push @remove_filters, $i;
+			}
+			++$i;
+		}
+		delete $selected_filters->[$_] for reverse @remove_filters;
+	}
+
+	1;
+}
+
 1;
